class HelloState(object):
    def __init__(self):
        self.calls = []

    def sayHello(self, int_value=None, string_value=None):
        print(int_value, string_value)
        self.calls.append((int_value, string_value))
        return "Said hello to {0}".format(string_value)

    class Java:
        implements = ["py4j.examples.IHello"]


class SimpleHello(object):

    def sayHello(self, int_value=None, string_value=None):
        print(int_value, string_value)
        return "Said hello to {0}".format(string_value)

    class Java:
        implements = ["py4j.examples.IHello"]


class RecursiveHello(object):

    def __init__(self, example_obj):
        self.example_obj = example_obj

    def sayHello(self, int_value=None, string_value=None):
        print(int_value, string_value)
        if int_value is None:
            print("Hello with no param")
            return self.example_obj.callHello2(self)
        else:
            print("Hello with 2 params")
            return "Said hello to {0}".format(string_value)

    class Java:
        implements = ["py4j.examples.IHello"]


class JavaHello(object):

    def __init__(self):
        self.clientserver = None

    def sayHello(self, int_value=None, string_value=None):
        ar = self.clientserver.jvm.java.util.ArrayList()
        ar.append("1")
        print(ar)
        other_value = self.clientserver.jvm.java.lang.\
            System.currentTimeMillis()
        print(int_value, string_value, other_value)
        return "Said hello to {0}".format(string_value)

    class Java:
        implements = ["py4j.examples.IHello"]


class PythonPing(object):

    def __init__(self, fail=False):
        self.fail = fail

    def ping1(self, obj):
        return obj.pong1(self)

    def ping2(self, obj):
        return obj.pong2(self)

    def ping3(self, obj):
        if self.fail:
            raise ValueError("Some Exception")
        else:
            return obj.pong3(self)

    class Java:
        implements = ["py4j.examples.IPing"]



"""
Created on Feb 2, 2016

@author: Nick White
"""
from __future__ import unicode_literals, absolute_import

from multiprocessing import Process
import subprocess
import unittest
import ssl
import os

from py4j.java_gateway import (
    JavaGateway, CallbackServerParameters,
    set_default_callback_accept_timeout, GatewayParameters)
from py4j.tests.java_gateway_test import (
    PY4J_JAVA_PATH, safe_shutdown, sleep)

set_default_callback_accept_timeout(0.125)


def start_example_tls_server():
    subprocess.call([
        "java", "-cp", PY4J_JAVA_PATH,
        "py4j.examples.ExampleSSLApplication"])


def start_example_tls_process():
    p = Process(target=start_example_tls_server)
    p.start()
    sleep()
    return p


class Adder(object):
    def doOperation(self, i, j):
        return i + j

    class Java:
        implements = ["py4j.examples.Operator"]


class TestIntegration(unittest.TestCase):
    """Tests cases borrowed from other files, but executed over a
    TLS connection.
    """
    def setUp(self):
        key_file = os.path.join(
            os.path.dirname(os.path.realpath(__file__)),
            "selfsigned.pem")

        client_ssl_context = ssl.SSLContext(ssl.PROTOCOL_TLSv1)
        client_ssl_context.verify_mode = ssl.CERT_REQUIRED
        client_ssl_context.check_hostname = True
        client_ssl_context.load_verify_locations(cafile=key_file)

        server_ssl_context = ssl.SSLContext(ssl.PROTOCOL_TLSv1)
        server_ssl_context.load_cert_chain(key_file, password='password')

        callback_server_parameters = CallbackServerParameters(
            ssl_context=server_ssl_context)
        # address must match cert, because we're checking hostnames
        gateway_parameters = GatewayParameters(
            address='localhost',
            ssl_context=client_ssl_context)

        self.p = start_example_tls_process()
        self.gateway = JavaGateway(
            gateway_parameters=gateway_parameters,
            callback_server_parameters=callback_server_parameters)
        # It seems SecureServerSocket may need a little more time to
        # initialize on some platforms/slow machines.
        sleep(0.500)

    def tearDown(self):
        safe_shutdown(self)
        self.p.join()
        sleep()

    def testUnicode(self):
        sleep()
        sb = self.gateway.jvm.java.lang.StringBuffer()
        sb.append("\r\n\tHello\r\n\t")
        self.assertEqual("\r\n\tHello\r\n\t", sb.toString())

    def testMethodConstructor(self):
        sleep()
        adder = Adder()
        oe1 = self.gateway.jvm.py4j.examples.OperatorExample()
        # Test method
        oe1.randomBinaryOperator(adder)
        # Test constructor
        oe2 = self.gateway.jvm.py4j.examples.OperatorExample(adder)
        self.assertIsNotNone(oe2)


if __name__ == "__main__":
    unittest.main()



from py4j.java_gateway import JavaGateway, CallbackServerParameters


class PythonListener(object):

    def __init__(self, gateway):
        self.gateway = gateway

    def notify(self, obj):
        print("Notified by Java")
        print(obj)
        gateway.jvm.System.out.println("Hello from python!")

        return "A Return Value"

    class Java:
        implements = ["py4j.examples.ExampleListener"]


if __name__ == "__main__":
    gateway = JavaGateway(
        callback_server_parameters=CallbackServerParameters())
    listener = PythonListener(gateway)
    gateway.entry_point.registerListener(listener)
    gateway.entry_point.notifyAllListeners()
    gateway.shutdown()



# coding: utf-8
"""
Compatibility functions for unified behavior between Python 2.x and 3.x.

:author: Alex Grönholm
"""
from __future__ import unicode_literals, absolute_import

import inspect
import sys
from threading import Thread

version_info = sys.version_info

if version_info.major < 3:
    def items(d):
        return d.items()

    def iteritems(d):
        return d.iteritems()

    def next(x):
        return x.next()

    range = xrange  # noqa

    long = long  # noqa

    basestring = basestring  # noqa

    unicode = unicode  # noqa

    bytearray2 = bytearray

    unichr = unichr  # noqa

    bytestr = str

    tobytestr = str

    def isbytestr(s):
        return isinstance(s, str)

    def ispython3bytestr(s):
        return False

    def isbytearray(s):
        return isinstance(s, bytearray)

    def bytetoint(b):
        return ord(b)

    def bytetostr(b):
        return b

    def strtobyte(b):
        return b

    import Queue
    Empty = Queue.Empty
    Queue = Queue.Queue

else:
    def items(d):
        return list(d.items())

    def iteritems(d):
        return d.items()

    next = next

    range = range

    long = int

    basestring = str

    unicode = str

    bytearray2 = bytes

    unichr = chr

    bytestr = bytes

    def tobytestr(s):
        return bytes(s, "ascii")

    def isbytestr(s):
        return isinstance(s, bytes)

    def ispython3bytestr(s):
        return isinstance(s, bytes)

    def isbytearray(s):
        return isinstance(s, bytearray)

    def bytetoint(b):
        return b

    def bytetostr(b):
        return str(b, encoding="ascii")

    def strtobyte(s):
        return bytes(s, encoding="ascii")

    import queue
    Queue = queue.Queue
    Empty = queue.Empty


if hasattr(inspect, "getattr_static"):
    def hasattr2(obj, attr):
        return bool(inspect.getattr_static(obj, attr, False))
else:
    hasattr2 = hasattr


class CompatThread(Thread):
    """Compatibility Thread class.

    Allows Python 2 Thread class to accept daemon kwarg in init.
    """

    def __init__(self, *args, **kwargs):
        daemon = None
        try:
            daemon = kwargs.pop("daemon")
        except KeyError:
            pass
        super(CompatThread, self).__init__(*args, **kwargs)

        if daemon:
            self.daemon = daemon
